@@ -144,28 +144,28 @@ def import_project_settings(file_name):
     return read.as_json(settings_path)
 
 
-def _parse_copy_data_from_obj(obj):
+def _parse_copy_data_from_obj(file_obj):
     data = {
         "src_path": None,
         "dst_path": None,
     }
-    if isinstance(obj, (tuple, list)):
-        if len(obj) == 2:
-            data['src_path'] = obj[0]
-            data['dst_path'] = obj[1]
+    if isinstance(file_obj, (tuple, list)):
+        if len(file_obj) == 2:
+            data['src_path'] = file_obj[0]
+            data['dst_path'] = file_obj[1]
         else:
             print(f"Invalid list/tuple provided for copy file. Must be [source_file_path, destination_file_path]")
-    if isinstance(obj, (dict)):
+    if isinstance(file_obj, (dict)):
         for syn in SRC_PATH_SYNONYMS:
             synvar = obj._gen_variations(syn)
             for sv in synvar:
-                if sv in obj:
-                    data['src_path'] = obj[sv]
+                if sv in file_obj:
+                    data['src_path'] = file_obj[sv]
         for syn in DEST_PATH_SYNONYMS:
             synvar = obj._gen_variations(syn)
             for sv in synvar:
-                if sv in obj:
-                    data['dst_path'] = obj[sv]
+                if sv in file_obj:
+                    data['dst_path'] = file_obj[sv]
 
     if exists(data['src_path']) is False:
         print(f"Invalid source path provided, {data['src_path']} could not be found.")
@@ -223,7 +223,7 @@ def copy(src, dest=False, **kwargs):
             If False, the files are copied one at a time.
 
         [`max_threads`=15] {int}
-            The total number of threads allowed to function simultaneously.  
+            The total number of threads allowed to function simultaneously.
 
         [`min_thread_threshold`=100] {int}
             There must be this many files to copy before threading is allowed.
@@ -267,6 +267,7 @@ def copy(src, dest=False, **kwargs):
             return
 
     _copy_files_from_array(copy_list)
+    print(f"copy_list: {copy_list}")
 
 
 def _copy_files_from_array(files):
@@ -298,3 +299,58 @@ def _thread_copy_files(files, **kwargs):
     for thread in threads:
         thread.join()
     return
+
+
+# files = [{
+#     "src_path": "C:\\Users\\Colemen\\Desktop\\TEST_FOLDER\\Mnemosyne Tests\\sourceDirectory\\rendering\\.picasa.ini",
+#     "dst_path": "C:\\Users\\Colemen\\Desktop\\TEST_FOLDER\\Mnemosyne Tests\\targetDirectory\\rendering\\.picasa.ini"
+# }, {
+#     "src_path": "C:\\Users\\Colemen\\Desktop\\TEST_FOLDER\\Mnemosyne Tests\\sourceDirectory\\rendering\\20211029151612812.jpg",
+#     "dst_path": "C:\\Users\\Colemen\\Desktop\\TEST_FOLDER\\Mnemosyne Tests\\targetDirectory\\rendering\\20211029151612812.jpg"
+# }, {
+#     "src_path": "C:\\Users\\Colemen\\Desktop\\TEST_FOLDER\\Mnemosyne Tests\\sourceDirectory\\rendering\\20211029151754458.jpg",
+#     "dst_path": "C:\\Users\\Colemen\\Desktop\\TEST_FOLDER\\Mnemosyne Tests\\targetDirectory\\rendering\\20211029151754458.jpg"
+# }, {
+#     "src_path": "C:\\Users\\Colemen\\Desktop\\TEST_FOLDER\\Mnemosyne Tests\\sourceDirectory\\rendering\\20211030002727270.jpg",
+#     "dst_path": "C:\\Users\\Colemen\\Desktop\\TEST_FOLDER\\Mnemosyne Tests\\targetDirectory\\rendering\\20211030002727270.jpg"
+# }, {
+#     "src_path": "C:\\Users\\Colemen\\Desktop\\TEST_FOLDER\\Mnemosyne Tests\\sourceDirectory\\rendering\\20211030002838887.jpg",
+#     "dst_path": "C:\\Users\\Colemen\\Desktop\\TEST_FOLDER\\Mnemosyne Tests\\targetDirectory\\rendering\\20211030002838887.jpg"
+# }, {
+#     "src_path": "C:\\Users\\Colemen\\Desktop\\TEST_FOLDER\\Mnemosyne Tests\\sourceDirectory\\rendering\\20211030002845943.jpg",
+#     "dst_path": "C:\\Users\\Colemen\\Desktop\\TEST_FOLDER\\Mnemosyne Tests\\targetDirectory\\rendering\\20211030002845943.jpg"
+# }, {
+#     "src_path": "C:\\Users\\Colemen\\Desktop\\TEST_FOLDER\\Mnemosyne Tests\\sourceDirectory\\rendering\\20211030003001713.jpg",
+#     "dst_path": "C:\\Users\\Colemen\\Desktop\\TEST_FOLDER\\Mnemosyne Tests\\targetDirectory\\rendering\\20211030003001713.jpg"
+# }, {
+#     "src_path": "C:\\Users\\Colemen\\Desktop\\TEST_FOLDER\\Mnemosyne Tests\\sourceDirectory\\rendering\\20211030003008915.jpg",
+#     "dst_path": "C:\\Users\\Colemen\\Desktop\\TEST_FOLDER\\Mnemosyne Tests\\targetDirectory\\rendering\\20211030003008915.jpg"
+# }, {
+#     "src_path": "C:\\Users\\Colemen\\Desktop\\TEST_FOLDER\\Mnemosyne Tests\\sourceDirectory\\rendering\\20211030005014600.jpg",
+#     "dst_path": "C:\\Users\\Colemen\\Desktop\\TEST_FOLDER\\Mnemosyne Tests\\targetDirectory\\rendering\\20211030005014600.jpg"
+# }, {
+#     "src_path": "C:\\Users\\Colemen\\Desktop\\TEST_FOLDER\\Mnemosyne Tests\\sourceDirectory\\rendering\\20211030011919612.jpg",
+#     "dst_path": "C:\\Users\\Colemen\\Desktop\\TEST_FOLDER\\Mnemosyne Tests\\targetDirectory\\rendering\\20211030011919612.jpg"
+# }, {
+#     "src_path": "C:\\Users\\Colemen\\Desktop\\TEST_FOLDER\\Mnemosyne Tests\\sourceDirectory\\rendering\\20211030011927976.jpg",
+#     "dst_path": "C:\\Users\\Colemen\\Desktop\\TEST_FOLDER\\Mnemosyne Tests\\targetDirectory\\rendering\\20211030011927976.jpg"
+# }, {
+#     "src_path": "C:\\Users\\Colemen\\Desktop\\TEST_FOLDER\\Mnemosyne Tests\\sourceDirectory\\rendering\\20211030014348434.jpg",
+#     "dst_path": "C:\\Users\\Colemen\\Desktop\\TEST_FOLDER\\Mnemosyne Tests\\targetDirectory\\rendering\\20211030014348434.jpg"
+# }, {
+#     "src_path": "C:\\Users\\Colemen\\Desktop\\TEST_FOLDER\\Mnemosyne Tests\\sourceDirectory\\rendering\\20211030014355273.jpg",
+#     "dst_path": "C:\\Users\\Colemen\\Desktop\\TEST_FOLDER\\Mnemosyne Tests\\targetDirectory\\rendering\\20211030014355273.jpg"
+# }, {
+#     "src_path": "C:\\Users\\Colemen\\Desktop\\TEST_FOLDER\\Mnemosyne Tests\\sourceDirectory\\rendering\\20211030022210268.jpg",
+#     "dst_path": "C:\\Users\\Colemen\\Desktop\\TEST_FOLDER\\Mnemosyne Tests\\targetDirectory\\rendering\\20211030022210268.jpg"
+# }, {
+#     "src_path": "C:\\Users\\Colemen\\Desktop\\TEST_FOLDER\\Mnemosyne Tests\\sourceDirectory\\rendering\\20211030022219671.jpg",
+#     "dst_path": "C:\\Users\\Colemen\\Desktop\\TEST_FOLDER\\Mnemosyne Tests\\targetDirectory\\rendering\\20211030022219671.jpg"
+# }, {
+#     "src_path": "C:\\Users\\Colemen\\Desktop\\TEST_FOLDER\\Mnemosyne Tests\\sourceDirectory\\rendering\\20211030022304089.jpg",
+#     "dst_path": "C:\\Users\\Colemen\\Desktop\\TEST_FOLDER\\Mnemosyne Tests\\targetDirectory\\rendering\\20211030022304089.jpg"
+# }, {
+#     "src_path": "C:\\Users\\Colemen\\Desktop\\TEST_FOLDER\\Mnemosyne Tests\\sourceDirectory\\rendering\\20211030022401058.jpg",
+#     "dst_path": "C:\\Users\\Colemen\\Desktop\\TEST_FOLDER\\Mnemosyne Tests\\targetDirectory\\rendering\\20211030022401058.jpg"
+# }]
+# copy(files)
